=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2005-03-29 11:49:50 +0000
+++ bzrlib/commands.py	2005-03-30 22:27:17 +0000
@@ -370,10 +370,22 @@
 
 
 def cmd_load_inventory():
-    inv = Branch('.').read_working_inventory()
-                
-    
-
+    inv = Branch('.').basis_tree().inventory
+
+
+
+def cmd_dump_new_inventory():
+    import bzrlib.newinventory
+    inv = Branch('.').basis_tree().inventory
+    bzrlib.newinventory.write_inventory(inv, sys.stdout)
+                
+    
+def cmd_dump_slacker_inventory():
+    import bzrlib.newinventory
+    inv = Branch('.').basis_tree().inventory
+    bzrlib.newinventory.write_slacker_inventory(inv, sys.stdout)
+                
+    
 
 def cmd_root(filename=None):
     """Print the branch root."""
@@ -838,7 +850,7 @@
         import hotshot.stats
         stats = hotshot.stats.load('.bzr.profile')
         #stats.strip_dirs()
-        stats.sort_stats('cumulative', 'calls')
+        stats.sort_stats('time')
         stats.print_stats(20)
     else:
         return cmd_handler(**cmdargs) or 0

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2005-03-29 07:29:29 +0000
+++ bzrlib/inventory.py	2005-03-30 22:27:17 +0000
@@ -458,10 +458,10 @@
         """Return as a list the path to file_id."""
         p = []
         while file_id != None:
-            ie = self[file_id]
-            p = [ie.name] + p
+            ie = self._byid[file_id]
+            p.insert(0, ie.name)
             file_id = ie.parent_id
-        return joinpath(p)
+        return '/'.join(p)
             
 
 
@@ -495,7 +495,6 @@
 
 
     def has_id(self, file_id):
-        assert isinstance(file_id, str)
         return self._byid.has_key(file_id)
 
 

=== added file 'bzrlib/newinventory.py'
--- bzrlib/newinventory.py	1970-01-01 00:00:00 +0000
+++ bzrlib/newinventory.py	2005-03-30 22:27:17 +0000
@@ -0,0 +1,58 @@
+# (C) 2005 Canonical Ltd
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from cElementTree import Element, ElementTree, SubElement
+
+
+def write_inventory(inv, f):
+    el = Element('inventory', {'version': '2'})
+    
+    root = Element('root_directory', {'id': 'bogus-root-id'})
+    el.append(root)
+
+    def descend(parent_el, ie):
+        kind = ie.kind
+        el = Element(kind, {'name': ie.name,
+                            'id': ie.file_id,})
+        
+        if kind == 'file':
+            if ie.text_id:
+                el.set('text_id', ie.text_id)
+            if ie.text_sha1:
+                el.set('text_sha1', ie.text_sha1)
+            if ie.text_size != None:
+                el.set('text_size', ('%d' % ie.text_size))
+        elif kind != 'directory':
+            bailout('unknown InventoryEntry kind %r' % kind)
+            
+        parent_el.append(el)
+
+        if kind == 'directory':
+            l = ie.children.items()
+            l.sort()
+            for child_name, child_ie in l:
+                descend(el, child_ie)
+                
+        
+    # walk down through inventory, adding all directories
+
+    l = inv._root.children.items()
+    l.sort()
+    for entry_name, ie in l:
+        descend(root, ie)
+    
+    ElementTree(el).write(f, 'utf-8')
+    f.write('\n')

=== added file 'notes/new-inventory-sample.xml'
--- notes/new-inventory-sample.xml	1970-01-01 00:00:00 +0000
+++ notes/new-inventory-sample.xml	2005-03-30 22:27:17 +0000
@@ -0,0 +1,108 @@
+<?xml version="1.0"?>
+<inventory version="2">
+  <root_directory id="bogus-root-id">
+    <file id="bzrignore-20050311232317-81f7b71efa2db11a" name=".bzrignore" text_id="bzrignore-20050329080130-e781c2df6eadf795" text_sha1="0c5a363290308bfad3cf7c307dc95bf4e495a39d" text_size="81"/>
+    <file id="NEWS-20050323055033-4e00b5db738777ff" name="NEWS" text_id="NEWS-20050329080130-24324023f7567123" text_sha1="11823c9e5ee9da113c6eeb6baae32097ec9673cc" text_size="1419"/>
+    <file id="README-20050309040720-8f368abf9f346b9d" name="README" text_id="README-20050326030328-7adde2dfd2e0dbbb" text_sha1="b68ae05d135d67a400245ab3aa9806b6a28abe11" text_size="1019"/>
+    <file id="build-api-20050309064830-a0be0dc1452cda87" name="build-api" text_id="build-api-20050309064900-aa74414b35b5e281" text_sha1="450452fd581a1f1ba1fb4bec349f49a8e8a226b3" text_size="75"/>
+    <file id="bzr.py-20050313053754-5485f144c7006fa6" name="bzr" text_id="bzr-20050319081938-21c30193cb7b9e70" text_sha1="afde3aee636065c59d4af92fe035b9d7fbdf6cac" text_size="919"/>
+    <directory id="bzrlib-20050309040749-4ac9a0e211602846" name="bzrlib">
+      <file id="__init__.py-20050309040759-33e65acf91bbcd5d" name="__init__.py" text_id="__init__.py-20050328023935-fe6007f48dde344b" text_sha1="3f4bbd0540a1f6c3dfde11b65e59c11e266d779a" text_size="1485"/>
+      <file id="add.py-20050323030017-3a77d63feda58e33" name="add.py" text_id="add.py-20050327095302-b3edf909f0f81011" text_sha1="53ed9ff67fcc9e1af47d6a4d484fb75b385a6ed4" text_size="2905"/>
+      <file id="branch.py-20050309040759-e4baf4e0d046576e" name="branch.py" text_id="branch.py-20050326134153-f3dff98b574258fd" text_sha1="6a6e9163a74bbdaa3e842019b4cc7258aa80e7ad" text_size="27666"/>
+      <file id="check.py-20050309040759-f3a679400c06bcc1" name="check.py" text_id="check.py-20050329003252-a7262eda3a08f596" text_sha1="21c85347e72f617da56a621e77b30bf0f98a9f05" text_size="4136"/>
+      <file id="bzr.py-20050309040720-d10f4714595cf8c3" name="commands.py" text_id="commands.py-20050329114950-3ea1014fdadfe60e" text_sha1="ec9f6768ec4c729b58af4e08c11b18608a065b21" text_size="24888"/>
+      <file id="diff.py-20050309040759-26944fbbf2ebbf36" name="diff.py" text_id="diff.py-20050309040815-f0112c3b71bc202c" text_sha1="84729acb8afb74b285e635a7c09a38f63b14fee4" text_size="5290"/>
+      <file id="errors.py-20050309040759-20512168c4e14fbd" name="errors.py" text_id="errors.py-20050309040815-75b5f741f053d362" text_sha1="ca6731c62e3d746d1d0a90d9a4ff4c744ac98e83" text_size="1170"/>
+      <file id="info.py-20050323235939-6bbfe7d9700b0b9b" name="info.py" text_id="info.py-20050328024049-e66d2a23d130aa83" text_sha1="e331ce0bc51cfab9aa6eec18d7a1976e384b3a35" text_size="3304"/>
+      <file id="inventory.py-20050309040759-6648b84ca2005b37" name="inventory.py" text_id="inventory.py-20050329072929-15ad4d139ebe9368" text_sha1="87ecb4851198f1b41a397e2f9708376a69edde19" text_size="15054"/>
+      <file id="osutils.py-20050309040759-eeaff12fbf77ac86" name="osutils.py" text_id="osutils.py-20050329023134-4968f3ab1cb80d22" text_sha1="bec87e1bcdfc50cd8b2ee5c4f014d4a3650fb12a" text_size="7405"/>
+      <file id="revision.py-20050309040759-e77802c08f3999d5" name="revision.py" text_id="revision.py-20050312073831-a24ec3db352a0db5" text_sha1="f3013ccb7c45a9bb340328eced6dc4d11d0bc61e" text_size="2830"/>
+      <file id="store.py-20050309040759-164dc5173d6406c2" name="store.py" text_id="store.py-20050329012619-9187f36afe5f02fe" text_sha1="f8fe399336db9b608ec7d866a042c3c84e1f6212" text_size="5285"/>
+      <file id="tests.py-20050309040759-b2da7bf735c06b1f" name="tests.py" text_id="tests.py-20050326134153-0a5950308e43bf54" text_sha1="a1715e90a1a4568b1464a290057435c3ef4fdfaa" text_size="5574"/>
+      <file id="textui.py-20050309040759-5d0cebe09c528e7d" name="textui.py" text_id="textui.py-20050309040815-3605bf769ab4eaf1" text_sha1="a5cb825012e2b2e7797b25139e72d1240675c9de" text_size="1017"/>
+      <file id="trace.py-20050309040759-c8ed824bdcd4748a" name="trace.py" text_id="trace.py-20050328041243-e744e720fe028769" text_sha1="7ca91f974741f05b1ecda92fb2a9b06210e33da8" text_size="3549"/>
+      <file id="tree.py-20050309040759-9d5f2496be663e77" name="tree.py" text_id="tree.py-20050329080130-b62bcff71cd143be" text_sha1="fdf9556da1b2de8b6354aa5bd4c9813123835b96" text_size="13679"/>
+      <file id="xml.py-20050309040759-57d51586fdec365d" name="xml.py" text_id="xml.py-20050315051954-b18360320fd01696" text_sha1="ed94ba5b8af981d007e3ad06083cfe7cc1f1c172" text_size="1556"/>
+    </directory>
+    <directory id="doc-20050309044934-a811c79dd26eef58" name="doc">
+      <file id="Makefile-20050309064830-17b60435388a9520" name="Makefile" text_id="Makefile-20050328022353-1fac836fcad1c3ab" text_sha1="04c5ac50d22caa71223dce1c1723f4927c2eada4" text_size="192"/>
+      <file id="adoption.txt-20050309044946-816486d97a97c5c5" name="adoption.txt" text_id="adoption.txt-20050309045105-1a9c10fb45e803e8" text_sha1="d8a42556a2bf39fdde914ea496761df591e76b56" text_size="4504"/>
+      <file id="bitkeeper.txt-20050309044946-9e207c5bfce2670f" name="bitkeeper.txt" text_id="bitkeeper.txt-20050309045105-fd4be07e5b1e2776" text_sha1="4e33c092641f44a71cd96617e7a20f9e4b6386f6" text_size="898"/>
+      <file id="changelogs.txt-20050309044946-cdc40a9f9ddece03" name="changelogs.txt" text_id="changelogs.txt-20050309045105-f3425da69c90bc3f" text_sha1="650b8344a9e1af3afaa0b5d72b3775f036d9a54a" text_size="1320"/>
+      <file id="cherry-picking.txt-20050309044946-d14f736fdb588e8f" name="cherry-picking.txt" text_id="cherry-picking.txt-20050309045105-3ab30173396c9944" text_sha1="03832e529e9a319b0a2bf5a6157691d2025204aa" text_size="1632"/>
+      <file id="cmdref.txt-20050309044946-d9a444af4c8e2d8b" name="cmdref.txt" text_id="cmdref.txt-20050309045105-af9ab0e5f5d15df0" text_sha1="4b5b544493a96eaa24cda0e41602772591b085f2" text_size="25271"/>
+      <file id="common-format.txt-20050309044946-48fc9f627ac98c0a" name="common-format.txt" text_id="common-format.txt-20050309045105-82969da54b78f851" text_sha1="518e2a235b398bc0aa6e26a9a9bcaa227ce8d5eb" text_size="1092"/>
+      <file id="compared-aegis.txt-20050309044946-2c8b94a645654397" name="compared-aegis.txt" text_id="compared-aegis.txt-20050309045105-70ed007ce0982df5" text_sha1="a0f8e26276a435165d919a4d77eaca4871df88d9" text_size="4275"/>
+      <file id="compared-codeville.txt-20050309044946-1cb208cab910fa50" name="compared-codeville.txt" text_id="compared-codeville.txt-20050312085410-65820cfb547ac6ad" text_sha1="0e5452aae2c7d0dc2530a871df54564d09544bf4" text_size="4145"/>
+      <file id="compared-cvsnt.txt-20050309044946-5396218e1b8351fb" name="compared-cvsnt.txt" text_id="compared-cvsnt.txt-20050309045105-b2dd9d47ab90b632" text_sha1="491675da9b7cb26f222af6dcb2b00406fd06a4e6" text_size="816"/>
+      <file id="compared-opencm.txt-20050309044946-e7ddc908a19c87f5" name="compared-opencm.txt" text_id="compared-opencm.txt-20050309045105-92619d5a43a54851" text_sha1="957b510ff6e162b2b8a9ffd23478059c41ab3889" text_size="1220"/>
+      <file id="compared-prcs.txt-20050309044946-f7c399f458e1fb59" name="compared-prcs.txt" text_id="compared-prcs.txt-20050309045105-61f3870a3561bcae" text_sha1="b126391a028eac75db56b6c2d4a8fc65fd2287f1" text_size="1483"/>
+      <file id="compared-teamware.txt-20050309044946-8d9e164d94ba5a7c" name="compared-teamware.txt" text_id="compared-teamware.txt-20050309045105-1be6ce2995f6fe09" text_sha1="3c50a4d42a10b12d19590a4569a7ae80dbc2b43b" text_size="1123"/>
+      <file id="compression.txt-20050309044946-a73f1e60c40ee57d" name="compression.txt" text_id="compression.txt-20050309045105-033c43c42527006d" text_sha1="a7a0896daff05d98a0b44b29d332113854c25a4c" text_size="2453"/>
+      <file id="config-specs.txt-20050309044946-d9820c58b7f23437" name="config-specs.txt" text_id="config-specs.txt-20050309045105-6cd36c4900778e23" text_sha1="11ce81de2dce0e3e44c854cc607ccfeb009c14a3" text_size="1788"/>
+      <file id="conflicts.txt-20050309044946-b9f2aded67790400" name="conflicts.txt" text_id="conflicts.txt-20050309045105-b625f78a9d1aa3e9" text_sha1="f058f8352787dea8b41111a0a327f04daae76fad" text_size="1387"/>
+      <file id="costs.txt-20050309044946-57b65806cab34815" name="costs.txt" text_id="costs.txt-20050309045105-b164407881870dd5" text_sha1="1e15b93fae5ad627f256f8f4e44dbec7df9171c4" text_size="701"/>
+      <file id="darcs.txt-20050309044946-5dbd16bd2da081a4" name="darcs.txt" text_id="darcs.txt-20050323235210-62ff177fabaa5967" text_sha1="7db04d391bc6eb074ce5c2a705877d006d923190" text_size="2638"/>
+      <file id="deadly-sins.txt-20050309044946-b0453a1c48093054" name="deadly-sins.txt" text_id="deadly-sins.txt-20050309045105-38cb25a50d3b1157" text_sha1="00566c41dc686ce45e8b58c88afb34611b15ef6c" text_size="1585"/>
+      <file id="default.css-20050309064830-2b764767f5f259c8" name="default.css" text_id="default.css-20050309064900-d96676d92f48fd8c" text_sha1="7bcb9fe51bc6c900862cd7567bb8458cb9526644" text_size="3962"/>
+      <file id="design.txt-20050309044946-54973dca2e7aa16b" name="design.txt" text_id="design.txt-20050309045105-88fecfcf589e6fd6" text_sha1="841a4f912b726e7f0f6cb9e6c062e2703bdf6635" text_size="41787"/>
+      <file id="extra-commands.txt-20050309044946-74af949c5805df22" name="extra-commands.txt" text_id="extra-commands.txt-20050309045105-9c07bdbe483793bd" text_sha1="20472f13679beddf9366dbf218bea3cb90d00509" text_size="695"/>
+      <file id="faq.txt-20050309044946-87b18fde82cf414a" name="faq.txt" text_id="faq.txt-20050309045105-adc8655244525a7a" text_sha1="88713c58c3162cbedfd14c57469829aec6041b58" text_size="231"/>
+      <file id="formats.txt-20050309044946-7ea328cdb5cae6c5" name="formats.txt" text_id="formats.txt-20050322000245-4982990c48231f44" text_sha1="55106e6b47f6966dc5b3b72bfc2f3573bd2eb8d0" text_size="8161"/>
+      <file id="hashes.txt-20050309044946-7a7382d0d715151f" name="hashes.txt" text_id="hashes.txt-20050309045105-63587dc15501b6d2" text_sha1="c4d42f8209bec59ef8fb90b730f6d06448e27efe" text_size="2560"/>
+      <file id="ignore.txt-20050328001329-d89006518f61dd00" name="ignore.txt" text_id="ignore.txt-20050328022418-43a7fd05366b06f2" text_sha1="0e45bf3560ed78053ec7b088c11173aa08195ef0" text_size="654"/>
+      <file id="index.txt-20050309044946-be91bf1c15711e5f" name="index.txt" text_id="index.txt-20050328001404-0eab78b497aeade5" text_sha1="00c098809e185488d567226d48c49df498c0cdc1" text_size="5790"/>
+      <file id="interrupted.txt-20050309044946-b6074892ab231e63" name="interrupted.txt" text_id="interrupted.txt-20050309045105-fd981a331efdf680" text_sha1="0ca1b2820e2c99656315211ccd70f5a8a52a2898" text_size="4293"/>
+      <file id="intro.txt-20050309044946-5bb22ffbfa8bfc14" name="intro.txt" text_id="intro.txt-20050309045105-d98d5268094fa375" text_sha1="b97bea4c5baf0a826683fe2ce0b823f8f9a608c2" text_size="3379"/>
+      <file id="inventory.txt-20050309044946-07534ab6d8b3c324" name="inventory.txt" text_id="inventory.txt-20050309045105-fa6637d533fd707e" text_sha1="c4c2fb6973502b1a4b18ab53332cb727c465c340" text_size="312"/>
+      <file id="join-branches.txt-20050309044946-f635037a889c0388" name="join-branches.txt" text_id="join-branches.txt-20050309045105-fea7e1f5b49b41c2" text_sha1="b8148e34e1546e83acf1ed32f4ec4bb4cc3502ae" text_size="3260"/>
+      <file id="kill-version.txt-20050309044946-1b9d175ca38c872c" name="kill-version.txt" text_id="kill-version.txt-20050309045105-ff4fe197ed67a40d" text_sha1="65084715a68dc4a22f60ed46cfa1c81441f14100" text_size="3560"/>
+      <file id="layers.txt-20050309044946-a48f19d7e271ec87" name="layers.txt" text_id="layers.txt-20050309045105-cd42b07df59a768d" text_sha1="34f97443035d3f286a136eaf485169b355483efa" text_size="2867"/>
+      <file id="library-interface.txt-20050309044946-97a60acc594383cc" name="library-interface.txt" text_id="library-interface.txt-20050309045105-27a374e4890d74c9" text_sha1="d5c6c86b8dcbcc0a06f01ddb680466d19e0e2329" text_size="326"/>
+      <file id="merge.txt-20050309044946-5d1ff42572fb3086" name="merge.txt" text_id="merge.txt-20050309045105-495a4a5b8553fe6f" text_sha1="f95f7a04bca711cab1ca528a79ba3174275b95dd" text_size="758"/>
+      <file id="mirroring.txt-20050309044946-eb411f73887829b1" name="mirroring.txt" text_id="mirroring.txt-20050309045105-63ff2af43ce824c7" text_sha1="f9473f6f98e5d139af3489169459b33f238c6d09" text_size="393"/>
+      <file id="monotone.txt-20050309044946-dd2abf24d99d201f" name="monotone.txt" text_id="monotone.txt-20050309045105-8fb6ac30e651a5b8" text_sha1="0b3c1d7d437ceb3b4f9964bae9846b5aa3a69953" text_size="595"/>
+      <file id="news.txt-20050309044946-02b97194f31e86e0" name="news.txt" text_id="news.txt-20050309045105-e3cc2094a8bd32ac" text_sha1="709e86f1545aaf38d2caed6db3b150ac65a72a55" text_size="4434"/>
+      <file id="optional-edit.txt-20050309044946-eddc8e1d07ae10a8" name="optional-edit.txt" text_id="optional-edit.txt-20050309045105-9c7c7616d9ed5c58" text_sha1="c5bbe7b8d2cd7ed53c3a4e989213915a3419654d" text_size="951"/>
+      <file id="partial-commit.txt-20050309044946-76fa39222d4fcc58" name="partial-commit.txt" text_id="partial-commit.txt-20050309045105-ebd00caf089392ea" text_sha1="4a4825f373c3d6ccb1614d8c9a717bdc23267603" text_size="880"/>
+      <file id="pool.txt-20050309044946-4a2400814cb5087a" name="pool.txt" text_id="pool.txt-20050309045105-a146ad389b36ecef" text_sha1="68002fb614f9f22e07774f259d54e0e17f361b3d" text_size="2930"/>
+      <file id="purpose.txt-20050309044946-a4132525edac8d4c" name="purpose.txt" text_id="purpose.txt-20050321222949-ba749c2169e3dba0" text_sha1="711070a417d92af93d99430a478c593e6565dfe3" text_size="3145"/>
+      <file id="python.txt-20050309044946-9eeeab2c3546abe6" name="python.txt" text_id="python.txt-20050309045105-73f03ec782191b18" text_sha1="067a8357e841178ec89dbb76073c0c429e7633a8" text_size="4230"/>
+      <file id="quickref.txt-20050309044946-e118485499fadee0" name="quickref.txt" text_id="quickref.txt-20050309045105-af9c9832b3ab7fec" text_sha1="30f46dd441dbbd797e4dd111e106071bc24423de" text_size="549"/>
+      <file id="quilt.txt-20050309044946-00df099b997fed5e" name="quilt.txt" text_id="quilt.txt-20050309045105-f9eb948a305b247f" text_sha1="3d8613f245558097d280b756eec3cd2e19fbaa36" text_size="253"/>
+      <file id="random.txt-20050309044946-269c29512b381f5b" name="random.txt" text_id="random.txt-20050321222949-4cbd779bfebd936a" text_sha1="0c9400360472e0305b120dbbebf12788880f7ceb" text_size="8529"/>
+      <file id="requirements.txt-20050309044946-f01e5318ade63900" name="requirements.txt" text_id="requirements.txt-20050309045105-91208951f02f4d5c" text_sha1="7118ac308a4799ed8146c94fb5fd9dde2cf2789d" text_size="1030"/>
+      <file id="revision-syntax.txt-20050309044946-86b3a8e902a15fa4" name="revision-syntax.txt" text_id="revision-syntax.txt-20050309045105-ca2db9854ac402c0" text_sha1="c84b833a1dd795f4a65b9adabfdc9b3fb1159112" text_size="2445"/>
+      <file id="roadmap.txt-20050309044946-fd8a18ed2f6049f1" name="roadmap.txt" text_id="roadmap.txt-20050309045105-aa821d48d65a3646" text_sha1="86d8823ae029e7617a5527597602412c5aed744f" text_size="1480"/>
+      <file id="rollup.txt-20050309044946-e551f4f85db5a5a0" name="rollup.txt" text_id="rollup.txt-20050309045105-5801a84a4015957e" text_sha1="25d713bab1a5abc198358fedf6a414a00bf3f0df" text_size="2640"/>
+      <file id="scalability.txt-20050309044946-646ac26c7fd65298" name="scalability.txt" text_id="scalability.txt-20050309045105-572fbf8f67f12009" text_sha1="50b3aadd75b7478e68adc7818733783730d8ac3f" text_size="650"/>
+      <file id="security.txt-20050309044946-41f7c6000b1124d0" name="security.txt" text_id="security.txt-20050309045105-68e6d4d9a4574959" text_sha1="cb20cb44a6d5e421721396cf1ab5c648dd4d72ae" text_size="14662"/>
+      <file id="shared-branches.txt-20050309044946-20521acf9bda9528" name="shared-branches.txt" text_id="shared-branches.txt-20050309045105-7cbd7b176765a7b5" text_sha1="1b7eaedcaed0af15f431a398366b5a4f58a17927" text_size="5834"/>
+      <file id="short-demo.txt-20050309044946-2145761a6909b03e" name="short-demo.txt" text_id="short-demo.txt-20050309045105-acdbb8f1a3cde539" text_sha1="d5d95a0760231aa75584669546b1b29de26696f7" text_size="5732"/>
+      <file id="supportability.txt-20050309044946-92aeba826c90201b" name="supportability.txt" text_id="supportability.txt-20050309045105-3b42b97911c05906" text_sha1="2a393e5c052cfd6aafdec621185fd7415ef1152f" text_size="841"/>
+      <file id="svk.txt-20050309044946-c62acd7cee590d22" name="svk.txt" text_id="svk.txt-20050309045105-dec97635b569da41" text_sha1="a485ca74f87cc0baca211c8344bf31c11ee87389" text_size="422"/>
+      <file id="tagging.txt-20050309044946-66adf967ad987472" name="tagging.txt" text_id="tagging.txt-20050309045105-3477d840eb290fe3" text_sha1="39da37ca4d619169492365c917452127074e4aeb" text_size="3135"/>
+      <file id="taxonomy.txt-20050309044946-922fe1158868767f" name="taxonomy.txt" text_id="taxonomy.txt-20050309045105-d0be06847dc3a1ff" text_sha1="0ce01e87ad97edc9d25ba3c5b45dad4cad6b2084" text_size="1819"/>
+      <file id="testing.txt-20050309044946-ea100200833c223a" name="testing.txt" text_id="testing.txt-20050309045105-a7b901188c51574b" text_sha1="633cab6bde0535401ac9eabead45d96c90e600bc" text_size="773"/>
+      <file id="thanks.txt-20050309044946-58141ea3091846d8" name="thanks.txt" text_id="thanks.txt-20050319014144-66b28b029f489391" text_sha1="c5ad6319f69f8e31d15bc36d4522a036493f6bd3" text_size="420"/>
+      <file id="todo-from-arch.txt-20050309044946-4cb8ccdf8b3fcd07" name="todo-from-arch.txt" text_id="todo-from-arch.txt-20050309045105-a0d73cedaa3cb912" text_sha1="fa95080711fd9a116643867d6e7b7dbd6458c01e" text_size="13588"/>
+      <file id="unchanged.txt-20050309044946-fe7d1ec585585702" name="unchanged.txt" text_id="unchanged.txt-20050309045105-b4a697341c602735" text_sha1="db90f5d3210f1392f45c27ba8eb3528847f9ee02" text_size="3920"/>
+      <file id="unrelated-merge.txt-20050309044946-ec165531264f1c99" name="unrelated-merge.txt" text_id="unrelated-merge.txt-20050309045105-dbe2b17d18728121" text_sha1="62b6d77942c44f16951219e7838f56f13dd0ae37" text_size="310"/>
+      <file id="usability.txt-20050309044946-57e59739a429628b" name="usability.txt" text_id="usability.txt-20050309045105-e9515f46e755dc0f" text_sha1="692295f407ced0cbad7bc2af2d42ae2aa4f2bec2" text_size="104"/>
+      <file id="use-cases.txt-20050309044946-19871d18448c91fc" name="use-cases.txt" text_id="use-cases.txt-20050309045105-c18c9210fa9c667b" text_sha1="4463f0219146a6d18801d8c90e046b8ce338662b" text_size="2679"/>
+      <file id="web-interface.txt-20050309044946-65ca85c7f551bf88" name="web-interface.txt" text_id="web-interface.txt-20050309045105-28c3ac23357d1194" text_sha1="90dcbc996c2d0187c774732c3947010e27204646" text_size="1024"/>
+      <file id="work-order.txt-20050309044946-4cfe50fc6e5258fe" name="work-order.txt" text_id="work-order.txt-20050309045105-fe2baee64418083c" text_sha1="c03413dbaff3e33536b02e7e41dc52ced07037c3" text_size="1778"/>
+      <file id="workflow.txt-20050309044946-d214d0e0429e719e" name="workflow.txt" text_id="workflow.txt-20050309045105-05ebdf3422fdcef6" text_sha1="69429a38371b5d3b6b850beb373467b4e6943a3b" text_size="5225"/>
+      <file id="yaml.txt-20050309044946-8d597bdf670d9095" name="yaml.txt" text_id="yaml.txt-20050309045105-65f6ca2247754aef" text_sha1="7d9b5a23639d0f1a03c97f983f17b41b79142db0" text_size="1376"/>
+    </directory>
+    <directory id="elementtree-20050323061618-ec49a4621bc7e4f4" name="elementtree">
+      <file id="ElementTree.py-20050323061623-cfa8eefe86f35391" name="ElementTree.py" text_id="ElementTree.py-20050323062555-7c291904c45fd0b9" text_sha1="aa97bbce740f09213293096bd1a9b8085999048b" text_size="36765"/>
+      <file id="__init__.py-20050323061623-61888e93152e298d" name="__init__.py" text_id="__init__.py-20050323062555-2183ef6f9f77dc96" text_sha1="6ecf754d86258e81ad6f76b01059dbd500cb3bfb" text_size="1491"/>
+    </directory>
+    <directory id="notes-20050309064844-c41b58b77e2b0876" name="notes">
+      <file id="performance.txt-20050309064844-d9647fd301942365" name="performance.txt" text_id="performance.txt-20050329114950-6c0e608dfda43e40" text_sha1="2598fc4b749b2e3d0ac12a44eff4a1fba48cf786" text_size="9288"/>
+    </directory>
+    <file id="setup.py-20050314065409-02f8a0a6e3f9bc70" name="setup.py" text_id="setup.py-20050314070724-fbe6913928cfa373" text_sha1="4a08c1c4b5d08bdec22d450e43686b12cf0cc210" text_size="472"/>
+  </root_directory>
+</inventory>

=== modified file 'notes/performance.txt'
--- notes/performance.txt	2005-03-29 11:49:50 +0000
+++ notes/performance.txt	2005-03-30 22:27:17 +0000
@@ -310,3 +310,12 @@
 Instead perhaps the Inventory object should hold the ElementTree and
 pull things out of it only as necessary?  We can even have an index
 pointing into the ElementTree by id, path, etc.
+
+
+as of r148
+
+bzr deleted  1.46s user 0.08s system 98% cpu 1.561 total
+
+
+Alternatively maybe keep an id2path and path2id cache?  Keeping it
+coherent may be hard...

